@@ -20,6 +20,7 @@ OC.L10N.register(
     "Invalid folder" : "Ungültiger Ordner",
     "Error while creating the account: " : "Fehler beim Erstellen eines Kontos:",
     "Unknown error" : "Unbekannter Fehler",
+    "Error while updating the account: " : "Fehler beim Aktualisieren des Kontos:",
     "All inboxes" : "Alle Posteingänge",
     "you" : "Du",
     "Send message to {email}" : "Nachricht an {email} senden",
@@ -33,6 +34,7 @@ OC.L10N.register(
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n neue Nachricht\nvon {from}","%n neue Nachrichten\nvon {from}"],
     "Nextcloud Mail" : "Nextcloud Mail",
     "Save" : "Speichern",
+    "Saved" : "Gespeichert",
     "Show all folders" : "Alle Ordner anzeigen",
     "Collapse folders" : "Ordner einklappen",
     "Error while deleting account." : "Fehler beim Löschen des Kontos.",
@@ -49,6 +51,7 @@ OC.L10N.register(
     "No writable calendars found" : "Keine beschreibbaren Kalender gefunden",
     "Error while importing the calendar event" : "Fehler beim Importieren des Kalenderereignis",
     "Error while downloading calendar event" : "Fehler beim Herunterladen des Kalenderereignis",
+    "& others" : "& weitere",
     "Error while loading messages." : "Fehler beim Laden der Nachrichten.",
     "Error while refreshing messages." : "Fehler beim Aktualisieren der Nachrichten.",
     "Setting up your account" : "Dein Konto wird eingerichtet",
@@ -61,9 +64,9 @@ OC.L10N.register(
     "All" : "Alle",
     "Favorites" : "Favoriten",
     "Auto detect failed. Please use manual mode." : "Automatische Erkennung fehlgeschlagen. Bitte nutze den manuellen Modus.",
+    "Updating account failed: " : "Kontoaktualisierung fehlgeschlagen:",
     "Creating account failed: " : "Kontoerstellung fehlgeschlagen:",
     "Delete permanently" : "Endgültig löschen",
-    "& others" : "& weitere",
     "Error loading message" : "Fehler beim Laden der Nachricht",
     "Settings" : "Einstellungen",
     "Forwarding to %s" : "Weiterleiten an %s",
@@ -79,6 +82,7 @@ OC.L10N.register(
     "Aliases" : "Aliasse",
     "Mail address" : "E-Mail-Adresse",
     "Display Name" : "Anzeigename",
+    "Account" : "Konto",
     "Keyboard shortcuts" : "Tastenkürzel",
     "Speed up your Mail experience with these quick shortcuts." : "Verbessere Deine Arbeit mit Mail durch diese Schnellbefehle.",
     "Compose new message" : "Neue Nachricht erstellen",
