@@ -20,6 +20,7 @@ OC.L10N.register(
     "Invalid folder" : "Invalid folder",
     "Error while creating the account: " : "Error while creating the account: ",
     "Unknown error" : "Unknown error",
+    "Error while updating the account: " : "Error while updating the account: ",
     "All inboxes" : "All inboxes",
     "you" : "you",
     "Send message to {email}" : "Send message to {email}",
@@ -33,6 +34,7 @@ OC.L10N.register(
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n new message \nfrom {from}","%n new messages \nfrom {from}"],
     "Nextcloud Mail" : "Nextcloud Mail",
     "Save" : "Save",
+    "Saved" : "Saved",
     "Show all folders" : "Show all folders",
     "Collapse folders" : "Collapse folders",
     "Error while deleting account." : "Error whilst deleting account.",
@@ -49,6 +51,7 @@ OC.L10N.register(
     "No writable calendars found" : "No writable calendars found",
     "Error while importing the calendar event" : "Error whilst importing the calendar event",
     "Error while downloading calendar event" : "Error whilst downloading calendar event",
+    "& others" : "& others",
     "Error while loading messages." : "Error whilst loading messages.",
     "Error while refreshing messages." : "Error while refreshing messages.",
     "Setting up your account" : "Setting up your account",
@@ -61,9 +64,9 @@ OC.L10N.register(
     "All" : "All",
     "Favorites" : "Favourites",
     "Auto detect failed. Please use manual mode." : "Auto detect failed. Please use manual mode.",
+    "Updating account failed: " : "Updating account failed: ",
     "Creating account failed: " : "Creating account failed: ",
     "Delete permanently" : "Delete permanently",
-    "& others" : "& others",
     "Error loading message" : "Error loading message",
     "Settings" : "Settings",
     "Forwarding to %s" : "Forwarding to %s",
@@ -79,6 +82,7 @@ OC.L10N.register(
     "Aliases" : "Aliases",
     "Mail address" : "Mail address",
     "Display Name" : "Display Name",
+    "Account" : "Account",
     "Keyboard shortcuts" : "Keyboard shortcuts",
     "Speed up your Mail experience with these quick shortcuts." : "Speed up your Mail experience with these quick shortcuts.",
     "Compose new message" : "Compose new message",
