@@ -20,6 +20,7 @@ OC.L10N.register(
     "Invalid folder" : "Carpeta inválida",
     "Error while creating the account: " : "Error al crear la cuenta:",
     "Unknown error" : "Error desconocido",
+    "Error while updating the account: " : "Error al actualizar la cuenta:",
     "All inboxes" : "Todas las bandejas de entrada",
     "you" : "usted",
     "Send message to {email}" : "Enviar mensaje a {email}",
@@ -33,6 +34,7 @@ OC.L10N.register(
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mensaje nuevo \nde {from}","%n mensajes nuevos\nde {from}"],
     "Nextcloud Mail" : "Correo de Nextcloud",
     "Save" : "Guardar",
+    "Saved" : "Guardado",
     "Show all folders" : "Mostrar todas las carpetas",
     "Collapse folders" : "Plegar carpetas",
     "Error while deleting account." : "Error al eliminar la cuenta.",
@@ -49,6 +51,7 @@ OC.L10N.register(
     "No writable calendars found" : "No se han encontrado calendarios con permiso de escritura",
     "Error while importing the calendar event" : "Error al importar el evento de calendario",
     "Error while downloading calendar event" : "Error al descargar el evento de calendario",
+    "& others" : "y otros",
     "Error while loading messages." : "Error al cargar los mensajes.",
     "Error while refreshing messages." : "Error al recargar los mensajes.",
     "Setting up your account" : "Configurando tu cuenta",
@@ -61,9 +64,9 @@ OC.L10N.register(
     "All" : "Todos",
     "Favorites" : "Favoritos",
     "Auto detect failed. Please use manual mode." : "La autodetección falló. Use el modo manual.",
+    "Updating account failed: " : "Fallo al actualizar la cuenta:",
     "Creating account failed: " : "No se pudo crear la cuenta:",
     "Delete permanently" : "Eliminar permanentemente",
-    "& others" : "y otros",
     "Error loading message" : "Error al cargar el mensaje",
     "Settings" : "Ajustes",
     "Forwarding to %s" : "Reenviando a %s",
@@ -79,6 +82,7 @@ OC.L10N.register(
     "Aliases" : "Alias",
     "Mail address" : "Dirección de correo electrónico",
     "Display Name" : "Nombre a mostrar",
+    "Account" : "Cuenta",
     "Keyboard shortcuts" : "Atajos de teclado",
     "Speed up your Mail experience with these quick shortcuts." : "Acelera tu experiencia de Correo con estos rápidos atajos de teclado.",
     "Compose new message" : "Crear nuevo mensaje",
