@@ -20,6 +20,7 @@ OC.L10N.register(
     "Invalid folder" : "Virheellinen kansio",
     "Error while creating the account: " : "Virhe tiliä luotaessa: ",
     "Unknown error" : "Tuntematon virhe",
+    "Error while updating the account: " : "Virhe päivittäessä tiliä:",
     "All inboxes" : "Kaikki saapuneiden laatikot",
     "you" : "sinä",
     "Send message to {email}" : "Lähetä viesti osoitteeseen {email}",
@@ -33,6 +34,7 @@ OC.L10N.register(
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n uusi viesti \nlähettäjältä {from}","%n uutta viestiä \nlähettäjältä {from}"],
     "Nextcloud Mail" : "Nextcloud-sähköposti",
     "Save" : "Tallenna",
+    "Saved" : "Tallennettu",
     "Show all folders" : "Näytä kaikki kansiot",
     "Collapse folders" : "Supista kansiot",
     "Error while deleting account." : "Virhe tiliä poistaessa.",
@@ -49,6 +51,7 @@ OC.L10N.register(
     "No writable calendars found" : "Kirjoitusoikeudella olevia kalentereita ei löytynyt",
     "Error while importing the calendar event" : "Virhe kalenteritapahtumaa tuotaessa",
     "Error while downloading calendar event" : "Virhe kalenteritapahtumaa ladatessa",
+    "& others" : "& muut",
     "Error while loading messages." : "Virhe viestejä ladatessa.",
     "Error while refreshing messages." : "Virhe viestejä päivittäessä.",
     "Setting up your account" : "Määritetään tiliäsi",
@@ -61,9 +64,9 @@ OC.L10N.register(
     "All" : "Kaikki",
     "Favorites" : "Suosikit",
     "Auto detect failed. Please use manual mode." : "Automaattinen havaitseminen epäonnistui. Käytä manuaalitilaa.",
+    "Updating account failed: " : "Tilin päivittäminen epäonnistui:",
     "Creating account failed: " : "Tilin luominen epäonnistui:",
     "Delete permanently" : "Poista pysyvästi",
-    "& others" : "& muut",
     "Error loading message" : "Virhe viestiä ladatessa",
     "Settings" : "Asetukset",
     "Forwarding to %s" : "Välitä viesti %s",
@@ -79,6 +82,7 @@ OC.L10N.register(
     "Aliases" : "Aliakset",
     "Mail address" : "Sähköpostiosoite",
     "Display Name" : "Näyttönimi",
+    "Account" : "Tili",
     "Keyboard shortcuts" : "Pikanäppäimet",
     "Speed up your Mail experience with these quick shortcuts." : "Nopeuta sähköpostikokemustasi näillä pikanäppäimillä.",
     "Compose new message" : "Uusi viesti",
