@@ -20,6 +20,7 @@ OC.L10N.register(
     "Invalid folder" : "Dossier invalide",
     "Error while creating the account: " : "Erreur lors de la création du compte:",
     "Unknown error" : "Erreur inconnue",
+    "Error while updating the account: " : "Erreur lors de la mise à jour du compte :",
     "All inboxes" : "Toutes les boîtes",
     "you" : "vous",
     "Send message to {email}" : "Envoyer un mail à {email}",
@@ -33,6 +34,7 @@ OC.L10N.register(
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nouveau message\nde {from}","%n nouveaux messages\nde {from}"],
     "Nextcloud Mail" : "Nextcloud Mail",
     "Save" : "Sauvegarder",
+    "Saved" : "Sauvegardé",
     "Show all folders" : "Montrer tous les dossiers",
     "Collapse folders" : "Replier les dossiers",
     "Error while deleting account." : "Erreur lors de la suppression du compte.",
@@ -49,6 +51,7 @@ OC.L10N.register(
     "No writable calendars found" : "Aucun calendrier modifiable n'a été trouvé",
     "Error while importing the calendar event" : "Erreur pendant l'importation de l'évènement du calendrier",
     "Error while downloading calendar event" : "Erreur pendant le téléchargement de l'évènement du calendrier",
+    "& others" : "et d'autres",
     "Error while loading messages." : "Erreur lors du chargement des messages.",
     "Error while refreshing messages." : "Erreur lors de l'actualisation des messages.",
     "Setting up your account" : "Paramétrage de votre compte",
@@ -61,9 +64,9 @@ OC.L10N.register(
     "All" : "Tous",
     "Favorites" : "Favoris",
     "Auto detect failed. Please use manual mode." : "L'auto-détection a échoué. Veuillez utiliser le mode manuel.",
+    "Updating account failed: " : "La mise à jour du compte a échoué : ",
     "Creating account failed: " : "La création du compte a échoué : ",
     "Delete permanently" : "Supprimer définitivement",
-    "& others" : "et d'autres",
     "Error loading message" : "Erreur lors du chargement du message",
     "Settings" : "Paramètres",
     "Forwarding to %s" : "Faire suivre à %s",
@@ -79,6 +82,7 @@ OC.L10N.register(
     "Aliases" : "Alias",
     "Mail address" : "Adresse mail",
     "Display Name" : "Nom affiché",
+    "Account" : "Compte",
     "Keyboard shortcuts" : "Raccourcis clavier",
     "Speed up your Mail experience with these quick shortcuts." : "Accélérez votre expérience Mail avec ces raccourcis rapides.",
     "Compose new message" : "Rédigez un nouveau message",
