@@ -20,6 +20,7 @@ OC.L10N.register(
     "Invalid folder" : "Érvénytelen mappa",
     "Error while creating the account: " : "Hiba történt a fiók létrehozásakor:",
     "Unknown error" : "Ismeretlen hiba",
+    "Error while updating the account: " : "Hiba történt a fiók frissítése közben:",
     "All inboxes" : "Minden bejövő",
     "you" : "te",
     "Send message to {email}" : "Üzenet küldés ide: {email}",
@@ -33,6 +34,7 @@ OC.L10N.register(
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n új üzenet \nfeladó: {from}","%n új üzenet \nfeladó: {from}"],
     "Nextcloud Mail" : "Nextcloud Mail",
     "Save" : "Mentés",
+    "Saved" : "Elmentve",
     "Show all folders" : "Minden mappa megjelenítése",
     "Collapse folders" : "Mappák összecsukása",
     "Error while deleting account." : "Hiba történt a fiók törlése közben.",
@@ -49,6 +51,7 @@ OC.L10N.register(
     "No writable calendars found" : "Nem található írható naptár",
     "Error while importing the calendar event" : "Hiba a naptár esemény importálása közben",
     "Error while downloading calendar event" : "Hiba a naptár esemény letöltése közben",
+    "& others" : "és mások",
     "Error while loading messages." : "Hiba történt az üzenetek betöltése közben.",
     "Error while refreshing messages." : "Hiba az üzenetek frissítése közben.",
     "Setting up your account" : "Fiókod beállítása",
@@ -61,9 +64,9 @@ OC.L10N.register(
     "All" : "Mind",
     "Favorites" : "Kedvencek",
     "Auto detect failed. Please use manual mode." : "Automatikus észlelés sikertelen. Használja a manuális módot.",
+    "Updating account failed: " : "Fiók frissítése sikertelen:",
     "Creating account failed: " : "Fiók létrehozása sikertelen: ",
     "Delete permanently" : "Végleges törlés",
-    "& others" : "és mások",
     "Error loading message" : "Hiba történt az üzenet betöltése közben",
     "Settings" : "Beállítások",
     "Forwarding to %s" : "Továbbítás ide: %s",
@@ -79,6 +82,7 @@ OC.L10N.register(
     "Aliases" : "Álnevek",
     "Mail address" : "E-mail cím",
     "Display Name" : "Megjelenített név",
+    "Account" : "Fiók",
     "Keyboard shortcuts" : "Gyorsbillentyűk",
     "Speed up your Mail experience with these quick shortcuts." : "Gyorsítsd fel a levelezési élményedet ezekkel a rövidítésekkel.",
     "Compose new message" : "Új üzenet írása",
