@@ -20,6 +20,7 @@ OC.L10N.register(
     "Invalid folder" : "Cartella non valida",
     "Error while creating the account: " : "Errore durante la creazione dell'account:",
     "Unknown error" : "Errore sconosciuto",
+    "Error while updating the account: " : "Errore durante l'aggiornamento dell'account:",
     "All inboxes" : "Tutte le caselle di posta",
     "you" : "tu",
     "Send message to {email}" : "Invia messaggio a {email}",
@@ -33,6 +34,7 @@ OC.L10N.register(
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nuovo messaggio \nda {from}","%n nuovi messaggi \nda {from}"],
     "Nextcloud Mail" : "Nextcloud Mail",
     "Save" : "Salva",
+    "Saved" : "Salvato",
     "Show all folders" : "Mostra tutte le cartelle",
     "Collapse folders" : "Contrai le cartelle",
     "Error while deleting account." : "Errore durante l'eliminazione dell'account.",
@@ -49,6 +51,7 @@ OC.L10N.register(
     "No writable calendars found" : "Nessun calendario scrivibile trovato",
     "Error while importing the calendar event" : "Errore durante l'importazione dell'evento di calendario",
     "Error while downloading calendar event" : "Errore durante lo scaricamento dell'evento di calendario",
+    "& others" : "e altri",
     "Error while loading messages." : "Errore durante il caricamento dei messaggi.",
     "Error while refreshing messages." : "Errore durante l'aggiornamento dei messaggi.",
     "Setting up your account" : "Configurazione del tuo account",
@@ -61,9 +64,9 @@ OC.L10N.register(
     "All" : "Tutti",
     "Favorites" : "Preferiti",
     "Auto detect failed. Please use manual mode." : "Rilevamento automatico non riuscito. Usa la modalità manuale.",
+    "Updating account failed: " : "Aggiornamento account non riuscito:",
     "Creating account failed: " : "Creazione account non riuscita:",
     "Delete permanently" : "Elimina definitivamente",
-    "& others" : "e altri",
     "Error loading message" : "Errore durante il caricamento del messaggio",
     "Settings" : "Impostazioni",
     "Forwarding to %s" : "Inoltro a %s",
@@ -79,6 +82,7 @@ OC.L10N.register(
     "Aliases" : "Alias",
     "Mail address" : "Indirizzo di posta",
     "Display Name" : "Nome visualizzato",
+    "Account" : "Account",
     "Keyboard shortcuts" : "Scorciatoie da tastiera",
     "Speed up your Mail experience with these quick shortcuts." : "Velocizza la tua esperienza di posta elettronica con queste scorciatoie.",
     "Compose new message" : "Componi nuovo messaggio",
