@@ -20,6 +20,7 @@ OC.L10N.register(
     "Invalid folder" : "არასწორი დირექტორია",
     "Error while creating the account: " : "ანგარიშის შექმნისას წარმოიშვა შეცდომა:",
     "Unknown error" : "უცნობი შეცდომა",
+    "Error while updating the account: " : "ანგარიშის განახლებისას წარმოიშვა შეცდომა:",
     "All inboxes" : "ყველა ინბოქსი",
     "you" : "თქვენ",
     "Send message to {email}" : "გაუგზავნეთ წერილი {email}-ს",
@@ -33,6 +34,7 @@ OC.L10N.register(
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ახალი წერილი\n{from}-ისგან"],
     "Nextcloud Mail" : "Nextcloud ფოსტა",
     "Save" : "შენახვა",
+    "Saved" : "შენახულია",
     "Show all folders" : "ყველა დირექტორიის ჩვენება",
     "Collapse folders" : "დირექტორიების კოლაფსი",
     "Error while deleting account." : "ანგარიშის გაუქმებისას წარმოიშვა შეცდომა.",
@@ -49,6 +51,7 @@ OC.L10N.register(
     "No writable calendars found" : "ჩაწერადი კალენდრები ვერ იქნა ნაპოვნი",
     "Error while importing the calendar event" : "კალენდრის მოვლენის იმპორტირებისას წარმოიშვა შეცდომა",
     "Error while downloading calendar event" : "კალენდრის მოვლენის ჩამოტვირთვისას წარმოიშვა შეცდომა",
+    "& others" : "და სხვები",
     "Error while loading messages." : "წერილების ჩატვირთვისას წარმოიშვა შეცდომა.",
     "Error while refreshing messages." : "წერილების განახლებისას წარმოიშვა შეცდომა.",
     "Setting up your account" : "ანგარიშის დაყენება",
@@ -61,9 +64,9 @@ OC.L10N.register(
     "All" : "ყველა",
     "Favorites" : "რჩეული",
     "Auto detect failed. Please use manual mode." : "ავტო-აღმოჩენა ვერ მოხერხდა. გთხოვთ სცადოთ ხელით.",
+    "Updating account failed: " : "ანგარიშის განახლება ვერ მოხერხდა:",
     "Creating account failed: " : "ანგარიშების შექმნა ვერ მოხერხდა:",
     "Delete permanently" : "სამუდამოდ წაშლა",
-    "& others" : "და სხვები",
     "Error loading message" : "წერილის ჩატვირთვისას წარმოიშვა შეცდომა",
     "Settings" : "პარამეტრები",
     "Forwarding to %s" : "გადაგზავნილია %s-ზე",
@@ -79,6 +82,7 @@ OC.L10N.register(
     "Aliases" : "სხვანაირი სახელი",
     "Mail address" : "ფოსტის მისამართი",
     "Display Name" : "დისპლეი სახელი",
+    "Account" : "ანგარიში",
     "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
     "Speed up your Mail experience with these quick shortcuts." : "მოიხმარეთ ეს კომბინაციები ფოსტასთან უფრო სწრაფად სამუშაოდ.",
     "Compose new message" : "ახალი წერილის შედგენა",
