@@ -20,6 +20,7 @@ OC.L10N.register(
     "Invalid folder" : "잘못된 폴더",
     "Error while creating the account: " : "계정 생성 중 오류 발생:",
     "Unknown error" : "알 수 없는 오류",
+    "Error while updating the account: " : "계정 업데이트 중 오류 발생:",
     "All inboxes" : "모든 받은 편지함",
     "you" : "나",
     "Send message to {email}" : "{email}(으)로 이메일 보내기",
@@ -33,6 +34,7 @@ OC.L10N.register(
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["새 메일 %n개\n보낸 사람: {from}"],
     "Nextcloud Mail" : "Nextcloud 메일",
     "Save" : "저장",
+    "Saved" : "저장됨",
     "Show all folders" : "모든 폴더 보기",
     "Collapse folders" : "폴더 접기",
     "Error while deleting account." : "계정을 삭제하는 중 오류가 발생했습니다.",
@@ -49,6 +51,7 @@ OC.L10N.register(
     "No writable calendars found" : "기록할 수 있는 달력을 찾을 수 없음",
     "Error while importing the calendar event" : "달력 행사를 가져 오는 중 오류 발생",
     "Error while downloading calendar event" : "달력 행사를 다운로드하는 중 오류 발생",
+    "& others" : "및 그 외",
     "Error while loading messages." : "메시지를 불러오는 중 오류가 발생했습니다.",
     "Error while refreshing messages." : "메시지를 새로 고치는 중 오류가 발생했습니다.",
     "Setting up your account" : "계정 설정 중",
@@ -61,9 +64,9 @@ OC.L10N.register(
     "All" : "전체 편지함",
     "Favorites" : "즐겨찾기",
     "Auto detect failed. Please use manual mode." : "자동 감지가 실패했습니다. 수동 모드를 사용하십시오.",
+    "Updating account failed: " : "계정 업데이트 실패:",
     "Creating account failed: " : "계정 생성 실패: ",
     "Delete permanently" : "영구히 삭제",
-    "& others" : "및 그 외",
     "Error loading message" : "메시지 불러오기 오류",
     "Settings" : "설정",
     "Forwarding to %s" : "%s 전달",
@@ -79,6 +82,7 @@ OC.L10N.register(
     "Aliases" : "별칭",
     "Mail address" : "메일 주소",
     "Display Name" : "표시 이름",
+    "Account" : "계정",
     "Keyboard shortcuts" : "키보드 단축키",
     "Speed up your Mail experience with these quick shortcuts." : "빠른 단축키로 메일 사용을 더 빠르게 할 수 있습니다.",
     "Compose new message" : "새 메시지 작성",
