@@ -20,6 +20,7 @@ OC.L10N.register(
     "Invalid folder" : "Ugyldig mappe",
     "Error while creating the account: " : "Feil under opprettelse av kontoen:",
     "Unknown error" : "Ukjent feil",
+    "Error while updating the account: " : "Feil under oppdatering av kontoen:",
     "All inboxes" : "Alle innbokser",
     "you" : "du",
     "Send message to {email}" : "Send melding til {email}",
@@ -33,6 +34,7 @@ OC.L10N.register(
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ny melding \nfra {from}","%n nye meldinger \nfra {from}"],
     "Nextcloud Mail" : "Nextcloud Mail",
     "Save" : "Lagre",
+    "Saved" : "Lagret",
     "Show all folders" : "Vis alle mapper",
     "Collapse folders" : "Skjul mapper",
     "Error while deleting account." : "Feil ved sletting av konto.",
@@ -49,6 +51,7 @@ OC.L10N.register(
     "No writable calendars found" : "Ingen skrivbare kalendere funnet",
     "Error while importing the calendar event" : "Feil ved importering av kalenderhendelse",
     "Error while downloading calendar event" : "Feil ved nedlasting av kalenderhendelse",
+    "& others" : "og andre",
     "Error while loading messages." : "Feil ved innlasting av meldinger.",
     "Error while refreshing messages." : "Feil under gjenoppfrisking av meldinger.",
     "Setting up your account" : "Oppsett av kontoen din",
@@ -61,9 +64,9 @@ OC.L10N.register(
     "All" : "Alle",
     "Favorites" : "Favoritter",
     "Auto detect failed. Please use manual mode." : "Automatisk påvisning mislyktes. Bruk manuelt oppsett.",
+    "Updating account failed: " : "Oppdatering av konto mislyktes:",
     "Creating account failed: " : "Oppretting av konto mislyktes:",
     "Delete permanently" : "Slett for godt",
-    "& others" : "og andre",
     "Error loading message" : "Feil ved innlasting av melding",
     "Settings" : "Innstillinger",
     "Forwarding to %s" : "Videresender til %s",
@@ -79,6 +82,7 @@ OC.L10N.register(
     "Aliases" : "Aliaser",
     "Mail address" : "E-postadresse",
     "Display Name" : "Visningsnavn",
+    "Account" : "Konto",
     "Keyboard shortcuts" : "Tastatursnarveier",
     "Speed up your Mail experience with these quick shortcuts." : "Arbeid raskere i Mail med disse raske snarveiene",
     "Compose new message" : "Lag ny melding",
