@@ -20,6 +20,7 @@ OC.L10N.register(
     "Invalid folder" : "Pasta inválida",
     "Error while creating the account: " : "Erro ao criar a conta:",
     "Unknown error" : "Erro desconhecido",
+    "Error while updating the account: " : "Erro ao atualizar a conta:",
     "All inboxes" : "Todas as caixas de entrada",
     "you" : "você",
     "Send message to {email}" : "Enviar mensagem para {email}",
@@ -33,6 +34,7 @@ OC.L10N.register(
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nova mensagem \nde {from}","%n novas mensagens \nde {from}"],
     "Nextcloud Mail" : "Email Nextcloud",
     "Save" : "Salvar",
+    "Saved" : "Salvo",
     "Show all folders" : "Mostrar todas as pastas",
     "Collapse folders" : "Esconder as pastas",
     "Error while deleting account." : "Erro ao excluir a conta.",
@@ -49,6 +51,7 @@ OC.L10N.register(
     "No writable calendars found" : "Não foi encontrado nenhum calendário que possa ser editado",
     "Error while importing the calendar event" : "Erro ao importar o evento de calendário",
     "Error while downloading calendar event" : "Erro ao baixar evento de calendário",
+    "& others" : "& outros",
     "Error while loading messages." : "Erro ao carregar mensagens.",
     "Error while refreshing messages." : "Erro ao atualizar as mensagens.",
     "Setting up your account" : "Configurando sua conta",
@@ -61,9 +64,9 @@ OC.L10N.register(
     "All" : "Todos",
     "Favorites" : "Favoritos",
     "Auto detect failed. Please use manual mode." : "A auto detecção falhou. Por favor use o modo manual.",
+    "Updating account failed: " : "Falhou ao atualizar a conta:",
     "Creating account failed: " : "A criação de contas falhou:",
     "Delete permanently" : "Excluir permanentemente",
-    "& others" : "& outros",
     "Error loading message" : "Erro carregando mensagem",
     "Settings" : "Configurações",
     "Forwarding to %s" : "Encaminhando para %s",
@@ -79,6 +82,7 @@ OC.L10N.register(
     "Aliases" : "Apelido",
     "Mail address" : "Endereço de e-mail",
     "Display Name" : "Nome",
+    "Account" : "Conta",
     "Keyboard shortcuts" : "Atalhos de teclado",
     "Speed up your Mail experience with these quick shortcuts." : "Acelere o uso de seu e-mail com estes atalhos rápidos.",
     "Compose new message" : "Redigir nova mensagem",
