@@ -20,6 +20,7 @@ OC.L10N.register(
     "Invalid folder" : "Неверная папка",
     "Error while creating the account: " : "Ошибка создания учётной записи:",
     "Unknown error" : "Неизвестная ошибка",
+    "Error while updating the account: " : "Ошибка обновления учётной записи:",
     "All inboxes" : "Все входящие",
     "you" : "вы",
     "Send message to {email}" : "Отправить сообщения на {email}",
@@ -33,6 +34,7 @@ OC.L10N.register(
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n новое сообщение \nот {from}","%n новых сообщения \nот {from}","%n новых сообщений \nот {from}","%n новых сообщений \nот {from}"],
     "Nextcloud Mail" : "Почта Nextcloud",
     "Save" : "Сохранить",
+    "Saved" : "Сохранено",
     "Show all folders" : "Показать все папки",
     "Collapse folders" : "Свернуть папки",
     "Error while deleting account." : "Ошибка удаления учётной записи.",
@@ -49,6 +51,7 @@ OC.L10N.register(
     "No writable calendars found" : "Календари доступные для записи не найдены",
     "Error while importing the calendar event" : "Ошибка при импорте календарного события",
     "Error while downloading calendar event" : "Ошибка при скачивании календарного события",
+    "& others" : "и другие",
     "Error while loading messages." : "Ошибка пр загрузке изображений.",
     "Error while refreshing messages." : "Ошибка обновления списка писем.",
     "Setting up your account" : "Настраивается учётная запись",
@@ -61,9 +64,9 @@ OC.L10N.register(
     "All" : "Все",
     "Favorites" : "Избранное",
     "Auto detect failed. Please use manual mode." : "Не удалось автоматически определить настройки. Воспользуйтесь ручным режимом.",
+    "Updating account failed: " : "Ошибка обновления учётной записи:",
     "Creating account failed: " : "Ошибка создания учетной записи:",
     "Delete permanently" : "Удалить окончательно",
-    "& others" : "и другие",
     "Error loading message" : "Ошибка загрузки сообщения",
     "Settings" : "Настройки",
     "Forwarding to %s" : "Пересылка на %s",
@@ -79,6 +82,7 @@ OC.L10N.register(
     "Aliases" : "Псевдонимы",
     "Mail address" : "Почтовый адрес",
     "Display Name" : "Отображаемое имя",
+    "Account" : "Учётная запись",
     "Keyboard shortcuts" : "Комбинации клавиш",
     "Speed up your Mail experience with these quick shortcuts." : "Ускорьте работу с почтой использованием этих комбинаций клавиш.",
     "Compose new message" : "Создать новое сообщение",
