@@ -20,6 +20,7 @@ OC.L10N.register(
     "Invalid folder" : "Neplatný priečinok",
     "Error while creating the account: " : "Nastala chyba počas vytvárania účtu:",
     "Unknown error" : "Neznáma chyba",
+    "Error while updating the account: " : "Chyba pri aktualizácii účtu:",
     "All inboxes" : "Všetky doručené",
     "you" : "vy",
     "Send message to {email}" : "Odoslať správu na {email}",
@@ -33,6 +34,7 @@ OC.L10N.register(
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nová správa\nod {from}","%n nové správy\nod {from}","%n nových správ\nod {from}"],
     "Nextcloud Mail" : "Nextcloud Mail",
     "Save" : "Uložiť",
+    "Saved" : "Uložené",
     "Show all folders" : "Zobraziť všetky priečinky",
     "Collapse folders" : "Zvinúť priečinky",
     "Error while deleting account." : "Chyba pri mazaní účtu.",
@@ -49,6 +51,7 @@ OC.L10N.register(
     "No writable calendars found" : "Nenašli sa žiadne kalendáre s právom zápisu",
     "Error while importing the calendar event" : "Nastala chyba pri importovaní udalosti kalendára",
     "Error while downloading calendar event" : "Nastala chyba pri sťahovaní udalosti kalendára",
+    "& others" : "& iné",
     "Error while loading messages." : "Chyba počas načítavania správ.",
     "Error while refreshing messages." : "Chyba počas obnovovania správ.",
     "Setting up your account" : "Nastavenie vášho účtu",
@@ -61,9 +64,9 @@ OC.L10N.register(
     "All" : "Všetky",
     "Favorites" : "Obľúbené",
     "Auto detect failed. Please use manual mode." : "Automatická detekcia zlyhala. Prosím, použite manuálny režim.",
+    "Updating account failed: " : "Aktualizácia účtu zlyhala:",
     "Creating account failed: " : "Vytvorenie účtu zlyhalo:",
     "Delete permanently" : "Zmazať  natrvalo",
-    "& others" : "& iné",
     "Error loading message" : "Chyba načítavania správy",
     "Settings" : "Nastavenia",
     "Forwarding to %s" : "Preposielam na %s",
@@ -79,6 +82,7 @@ OC.L10N.register(
     "Aliases" : "Aliasy",
     "Mail address" : "Emailová adresa",
     "Display Name" : "Zobrazované meno",
+    "Account" : "Účet",
     "Keyboard shortcuts" : "Klávesové skratky",
     "Speed up your Mail experience with these quick shortcuts." : "Zefektívnite svoju prácu s Mailom pomocou týchto rýchlych skratiek.",
     "Compose new message" : "Nová správa",
