@@ -20,6 +20,7 @@ OC.L10N.register(
     "Invalid folder" : "Klasör geçersiz",
     "Error while creating the account: " : "Hesap eklenirken sorun çıktı:",
     "Unknown error" : "Bilinmeyen bir sorun çıktı",
+    "Error while updating the account: " : "Hesap güncellenirken sorun çıktı:",
     "All inboxes" : "Tüm gelen kutuları",
     "you" : "siz",
     "Send message to {email}" : "{email} adresine ileti gönder",
@@ -33,6 +34,7 @@ OC.L10N.register(
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n yeni ileti\ngönderen {from}","%n yeni ileti\ngönderen {from}"],
     "Nextcloud Mail" : "Nextcloud Posta",
     "Save" : "Kaydet",
+    "Saved" : "Kaydedildi",
     "Show all folders" : "Tüm klasörleri görüntüle",
     "Collapse folders" : "Klasörleri daralt",
     "Error while deleting account." : "Hesap silinirken sorun çıktı.",
@@ -49,6 +51,7 @@ OC.L10N.register(
     "No writable calendars found" : "Yazılabilecek bir takvim bulunamadı",
     "Error while importing the calendar event" : "Takvim etkinliği içe aktarılırken sorun çıktı",
     "Error while downloading calendar event" : "Takvim etkinliği indirilirken sorun çıktı",
+    "& others" : "ve diğer",
     "Error while loading messages." : "İletiler yüklenirken sorun çıktı.",
     "Error while refreshing messages." : "İletiler yenilenirken sorun çıktı.",
     "Setting up your account" : "Hesabınız ayarlanıyor",
@@ -61,9 +64,9 @@ OC.L10N.register(
     "All" : "Tümü",
     "Favorites" : "Sık Kullanılanlar",
     "Auto detect failed. Please use manual mode." : "Otomatik olarak algılanamadı. Lütfen el ile kipini kullanın.",
+    "Updating account failed: " : "Hesap güncellenemedi:",
     "Creating account failed: " : "Hesap oluşturulamadı:",
     "Delete permanently" : "Kalıcı olarak sil",
-    "& others" : "ve diğer",
     "Error loading message" : "İleti yüklenirken sorun çıktı",
     "Settings" : "Ayarlar",
     "Forwarding to %s" : "%s adresine iletiliyor",
@@ -79,6 +82,7 @@ OC.L10N.register(
     "Aliases" : "Kısaltmalar",
     "Mail address" : "Posta adresi",
     "Display Name" : "Görüntülenecek Ad",
+    "Account" : "Hesap",
     "Keyboard shortcuts" : "Tuş takımı kısayolları",
     "Speed up your Mail experience with these quick shortcuts." : "Kısayol tuşlarını kullanarak e-posta deneyiminizi hızlandırabilirsiniz.",
     "Compose new message" : "Yeni ileti gönder",
