@@ -20,6 +20,7 @@ OC.L10N.register(
     "Invalid folder" : "無效的收件匣",
     "Error while creating the account: " : "在建立該帳號時發生了異常：",
     "Unknown error" : "未知的錯誤",
+    "Error while updating the account: " : "更新帳戶時發生錯誤",
     "All inboxes" : "所有收件匣",
     "you" : "您",
     "Send message to {email}" : "寄信給 {email}",
@@ -33,6 +34,7 @@ OC.L10N.register(
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n則新信件\n來自 {from}"],
     "Nextcloud Mail" : "Nextcloud 郵件",
     "Save" : "儲存",
+    "Saved" : "已儲存",
     "Show all folders" : "顯示所有收件匣",
     "Collapse folders" : "收合收件匣",
     "Error while deleting account." : "刪除帳號時發生錯誤",
@@ -49,6 +51,7 @@ OC.L10N.register(
     "No writable calendars found" : "查無可寫入的日曆",
     "Error while importing the calendar event" : "匯入日曆事件時發生錯誤",
     "Error while downloading calendar event" : "下載日曆事件時發生錯誤",
+    "& others" : "和其他人",
     "Error while loading messages." : "載入信件時發生錯誤",
     "Error while refreshing messages." : "重新整理信件時發生錯誤",
     "Setting up your account" : "設定您的帳號",
@@ -61,9 +64,9 @@ OC.L10N.register(
     "All" : "所有",
     "Favorites" : "最愛",
     "Auto detect failed. Please use manual mode." : "自動偵測失敗，請改用手動輸入",
+    "Updating account failed: " : "更新帳戶失敗",
     "Creating account failed: " : "建立帳號失敗：",
     "Delete permanently" : "永久刪除",
-    "& others" : "和其他人",
     "Error loading message" : "載入信件錯誤",
     "Settings" : "設定",
     "Forwarding to %s" : "正在轉寄給%s",
@@ -79,6 +82,7 @@ OC.L10N.register(
     "Aliases" : "別名",
     "Mail address" : "郵件地址",
     "Display Name" : "顯示名稱",
+    "Account" : "帳戶",
     "Keyboard shortcuts" : "快速鍵",
     "Speed up your Mail experience with these quick shortcuts." : "使用快速鍵來加速您的操作體驗",
     "Compose new message" : "撰寫新信件",
@@ -114,6 +118,7 @@ OC.L10N.register(
     "Subject" : "主旨",
     "Save all to Files" : "全部儲存至檔案",
     "Add mail account" : "新增郵件帳戶",
+    "Use Gravatar and favicon avatars" : "使用個人化大頭貼與網站圖示",
     "No search results for" : "沒有搜尋到結果：",
     "The images have been blocked to protect your privacy." : "為維護您的隱私，圖片將不會被載入",
     "Show images from this sender" : "顯示來自此寄件者的圖片",
