@@ -37,10 +37,8 @@ use Horde_Imap_Client;
 use Horde_Imap_Client_Ids;
 use Horde_Imap_Client_Mailbox;
 use Horde_Imap_Client_Socket;
-use Horde_Mail_Rfc822_Address;
 use Horde_Mail_Rfc822_List;
 use Horde_Mail_Transport;
-use Horde_Mail_Transport_Mail;
 use Horde_Mail_Transport_Null;
 use Horde_Mail_Transport_Smtphorde;
 use Horde_Mime_Headers_Date;
@@ -146,7 +144,7 @@ class Account implements IAccount {
 				'secure' => $ssl_mode,
 				'timeout' => (int) $this->config->getSystemValue('app.mail.imap.timeout', 20),
 			];
-			if ($this->config->getSystemValue('app.mail.imaplog.enabled', false)) {
+			if ($this->config->getSystemValue('debug', false)) {
 				$params['debug'] = $this->config->getSystemValue('datadirectory') . '/horde_imap.log';
 			}
 			if ($this->config->getSystemValue('app.mail.server-side-cache.enabled', true)) {
@@ -166,6 +164,7 @@ class Account implements IAccount {
 
 	/**
 	 * @param string $mailBox
+	 * @param array $opts
 	 * @return Mailbox
 	 */
 	public function createMailbox($mailBox, $opts = []) {
@@ -180,18 +179,17 @@ class Account implements IAccount {
 	 * Send a new message or reply to an existing message
 	 *
 	 * @param IMessage $message
+	 * @param Horde_Mail_Transport $transport
 	 * @param int|null $draftUID
 	 * @return int message UID
 	 */
-	public function sendMessage(IMessage $message, $draftUID) {
+	public function sendMessage(IMessage $message, Horde_Mail_Transport $transport, $draftUID) {
 		// build mime body
-		$from = new Horde_Mail_Rfc822_Address($message->getFrom());
-		$from->personal = $this->getName();
 		$headers = [
-			'From' => $from,
-			'To' => $message->getToList(),
-			'Cc' => $message->getCCList(),
-			'Bcc' => $message->getBCCList(),
+			'From' => $message->getFrom()->first()->toHorde(),
+			'To' => $message->getTo()->toHorde(),
+			'Cc' => $message->getCC()->toHorde(),
+			'Bcc' => $message->getBCC()->toHorde(),
 			'Subject' => $message->getSubject(),
 		];
 
@@ -213,7 +211,6 @@ class Account implements IAccount {
 		}
 
 		// Send the message
-		$transport = $this->createTransport();
 		$mail->send($transport, false, false);
 
 		// Save the message in the sent folder
@@ -225,8 +222,6 @@ class Account implements IAccount {
 
 		// Delete draft if one exists
 		if (!is_null($draftUID)) {
-			$draftsFolder = $this->getDraftsFolder();
-			$draftsFolder->setMessageFlag($draftUID, Horde_Imap_Client::FLAG_DELETED, true);
 			$this->deleteDraft($draftUID);
 		}
 
@@ -240,13 +235,11 @@ class Account implements IAccount {
 	 */
 	public function saveDraft(IMessage $message, $previousUID) {
 		// build mime body
-		$from = new Horde_Mail_Rfc822_Address($message->getFrom());
-		$from->personal = $this->getName();
 		$headers = [
-			'From' => $from,
-			'To' => $message->getToList(),
-			'Cc' => $message->getCCList(),
-			'Bcc' => $message->getBCCList(),
+			'From' => $message->getFrom()->first()->toHorde(),
+			'To' => $message->getTo()->toHorde(),
+			'Cc' => $message->getCC()->toHorde(),
+			'Bcc' => $message->getBCC()->toHorde(),
 			'Subject' => $message->getSubject(),
 			'Date' => Horde_Mime_Headers_Date::create(),
 		];
@@ -266,8 +259,6 @@ class Account implements IAccount {
 
 		// delete old version if one exists
 		if (!is_null($previousUID)) {
-			$draftsFolder->setMessageFlag($previousUID, \Horde_Imap_Client::FLAG_DELETED,
-				true);
 			$this->deleteDraft($previousUID);
 		}
 
@@ -358,31 +349,6 @@ class Account implements IAccount {
 		return $this->account->toJson();
 	}
 
-	/**
-	 * @return Horde_Mail_Transport
-	 */
-	public function createTransport() {
-		$transport = $this->config->getSystemValue('app.mail.transport', 'smtp');
-		if ($transport === 'php-mail') {
-			return new Horde_Mail_Transport_Mail();
-		}
-
-		$password = $this->account->getOutboundPassword();
-		$password = $this->crypto->decrypt($password);
-		$params = [
-			'host' => $this->account->getOutboundHost(),
-			'password' => $password,
-			'port' => $this->account->getOutboundPort(),
-			'username' => $this->account->getOutboundUser(),
-			'secure' => $this->convertSslMode($this->account->getOutboundSslMode()),
-			'timeout' => (int) $this->config->getSystemValue('app.mail.smtp.timeout', 2)
-		];
-		if ($this->config->getSystemValue('app.mail.smtplog.enabled', false)) {
-			$params['debug'] = $this->config->getSystemValue('datadirectory') . '/horde_smtp.log';
-		}
-		return new Horde_Mail_Transport_Smtphorde($params);
-	}
-
 	/**
 	 * Lists special use folders for this account.
 	 *
@@ -510,13 +476,13 @@ class Account implements IAccount {
 	}
 
 	/**
-	 * 
 	 * @param int $messageId
 	 */
-	public function deleteDraft($messageId) {
+	private function deleteDraft($messageId) {
 		$draftsFolder = $this->getDraftsFolder();
-		
-		$draftsMailBox = new \Horde_Imap_Client_Mailbox($draftsFolder->getFolderId(), false);
+		$draftsFolder->setMessageFlag($messageId, Horde_Imap_Client::FLAG_DELETED, true);
+
+		$draftsMailBox = new Horde_Imap_Client_Mailbox($draftsFolder->getFolderId(), false);
 		$this->getImapConnection()->expunge($draftsMailBox);
 	}
 
@@ -678,9 +644,6 @@ class Account implements IAccount {
 		return $sslMode;
 	}
 
-	/**
-	}
-
 	/**
 	 * @return string|Horde_Mail_Rfc822_List
 	 */
@@ -688,14 +651,13 @@ class Account implements IAccount {
 		return $this->account->getEmail();
 	}
 
-	public function testConnectivity() {
+	public function testConnectivity(Horde_Mail_Transport $transport) {
 		// connect to imap
 		$this->getImapConnection();
 
 		// connect to smtp
-		$smtp = $this->createTransport();
-		if ($smtp instanceof Horde_Mail_Transport_Smtphorde) {
-			$smtp->getSMTPObject();
+		if ($transport instanceof Horde_Mail_Transport_Smtphorde) {
+			$transport->getSMTPObject();
 		}
 	}
 
